@@ -5,14 +5,14 @@
 
     A port of Ruby on Rails' inflector to Python.
 
-    :copyright: (c) 2012-2014 by Janne Vanhala
+    :copyright: (c) 2012-2015 by Janne Vanhala
 
     :license: MIT, see LICENSE for more details.
 """
 import re
 import unicodedata
 
-__version__ = '0.2.1'
+__version__ = '0.3.1'
 
 PLURALS = [
     (r"(?i)(quiz)$", r'\1zes'),
@@ -29,7 +29,7 @@ PLURALS = [
     (r"(?i)sis$", 'ses'),
     (r"(?i)([ti])a$", r'\1a'),
     (r"(?i)([ti])um$", r'\1a'),
-    (r"(?i)(buffal|tomat)o$", r'\1oes'),
+    (r"(?i)(buffal|potat|tomat)o$", r'\1oes'),
     (r"(?i)(bu)s$", r'\1ses'),
     (r"(?i)(alias|status)$", r'\1es'),
     (r"(?i)(octop|vir)i$", r'\1i'),
@@ -193,8 +193,8 @@ def humanize(word):
     """
     word = re.sub(r"_id$", "", word)
     word = word.replace('_', ' ')
-    word = re.sub(r"(?i)([a-z\d]*)", lambda match: match.group(1).lower(), word)
-    word = re.sub(r"^\w", lambda match: match.group(0).upper(), word)
+    word = re.sub(r"(?i)([a-z\d]*)", lambda m: m.group(1).lower(), word)
+    word = re.sub(r"^\w", lambda m: m.group(0).upper(), word)
     return word
 
 
@@ -331,6 +331,23 @@ def singularize(word):
     return word
 
 
+def tableize(word):
+    """
+    Create the name of a table like Rails does for models to table names. This
+    method uses the :func:`pluralize` method on the last word in the string.
+
+    Examples::
+
+        >>> tableize('RawScaledScorer')
+        "raw_scaled_scorers"
+        >>> tableize('egg_and_ham')
+        "egg_and_hams"
+        >>> tableize('fancyCategory')
+        "fancy_categories"
+    """
+    return pluralize(underscore(word))
+
+
 def titleize(word):
     """
     Capitalize all the words and replace some characters in the string to
@@ -398,6 +415,7 @@ def underscore(word):
 
 _irregular('person', 'people')
 _irregular('man', 'men')
+_irregular('human', 'humans')
 _irregular('child', 'children')
 _irregular('sex', 'sexes')
 _irregular('move', 'moves')
